%% Calculate intensity spectrum for c-axis pole figures
%  Version 1.1
%
% This script constructs the intensity spectrum in c-axis ODF pole figures
% at 5 degrees plunge. This routine allows the user to identify peaks 
% associated with orthorhombic and monoclinic c-axis symmetries and thus 
% semi-quantify coaxial and non-coaxial deformations, kinematics, vorticity 
% and opening angle geometries.
%
% Requires MATLAB R2012B or higher, and MTEX 4.0 or higher

clear all
%% Specify Crystal and Specimen Symmetries

% crystal symmetry
CS = crystalSymmetry('-3m', [4.916 4.916 5.4054], 'mineral', 'Quartz', 'color', 'light blue');

% specimen symmetry
SS = specimenSymmetry('1');

% plotting convention
setMTEXpref('xAxisDirection','east');
setMTEXpref('zAxisDirection','outOfPlane');
%% Specify File Names
%  NOTE: the file path will need to be changed based on the location of the
%  demo files! Please modify in scriptline 29

% path to files
pname = 'G:\MCT\Models';

% which files to be imported
fname = {...
  [pname '\demo_001.txt'],...
  [pname '\demo_100.txt'],...
  [pname '\demo_101.txt'],...
  [pname '\demo_110.txt'],...
  };
%% Specify Miller Indices

h = { ...
  Miller(0,0,1,CS),...
  Miller(1,0,0,CS),...
  Miller(1,0,1,CS),...
  Miller(1,1,0,CS),...
  };
%% Import the measured data
% create a Pole Figure variable containing the data
pf = loadPoleFigure(fname,h,CS,SS,'interface','generic',...
  'ColumnNames', { 'Latitude' 'Longitude' 'Intensity'});
%% Plot pole figures for visual inspection
plot(pf,'lower', 'contourf', 'contours', 13)
%% Create an ODF from measured data to complete texture
odf_quartz = calcODF(pf,'halfwidth',5*degree)
%% Set Miller Indices 
pfs_qtz_hkl = (...
    [Miller(0,0,0,3,CS,'Quartz','hkl')...
    Miller(1,1,-2,0,CS,'Quartz','hkl'),...
    ])
% list two : [uvw] [directions]
pfs_qtz_uvw = (...
    [Miller(0,0,0,3,CS,'Quartz','uvw')...
    Miller(1,1,-2,0,CS,'Quartz','uvw'),...
    ])
%% Plot 001 and 110 pole figures for inspection of ODF routine
figure
plotPDF(odf_quartz,pfs_qtz_hkl,'lower')
%% Calculate the intensity spectrum along 001 for theta = 5 degrees
%  Note that azimuth = 0 starts at 90 and rotates counter-clockwise.
r = vector3d('rho',(0:360)*degree,'theta',5);
intensity_raw = calcPDF(odf_quartz,Miller(0,0,1,odf_quartz.CS),r);
% Convert counter-clockwise to clockwise
intensity_rotate = flipud(intensity_raw);
% Modify data set to start at Y (0 degrees) in pole figure
intensity = circshift(intensity_rotate,90);
% Plot the figure
figure
plot(r.rho./degree,intensity)
set(gca, 'xtick', [-180 -150 -120 -90 -60 -30 0 30 60 90 120 150 180'])
set(gca, 'xtickLabel', {'0','30','60','90','120','150','180','210','240','270','300','330','360'})
xlabel('Azimuth of pole figure')
ylabel('Intensity')
% Return values for peaks (intensity, azimuth)
[pks_001, az_001] = findpeaks(intensity)
%% Calculate angle between highest density c-axis maxima and foliation normal (Z)
%
%  Used to assist in determining flow vorticity (Willis et al 1995).  
%   -x = sinistral
%   +x = dextral
%
% Top maxima
[c_max_t,id_max_001_t] = max(intensity)
c_max_angle_t = minus(90,id_max_001_t)
%% Calculate opening angles for c-axis pole figure
%
%  If an orthorhombic symmetry is detected, the opening angle can be
%  measured between crossing girdles.
%
% Detect four highest values associated with girdles
n = numel(pks_001);
id = [1:n]';
angle = [pks_001, az_001 id];
az_max = sortrows(angle, -1);
id_four = az_max(1:4, [2 3]);
id_four_sort = sortrows(id_four, 2);
% Take difference between north and south girdles and return the mean
oa_correct = minus(360, id_four_sort(4));
oa_top = plus(oa_correct,id_four_sort(1))
oa_bottom = minus(id_four_sort(3),id_four_sort(2))
mean_oa = (oa_top+oa_bottom)/2